magneticalc.QtWidgets2.QSliderFloat.QSliderFloat

# ``magneticalc`.`QtWidgets2`.`QSliderFloat`.`QSliderFloat``

class documentation

`class QSliderFloat(QSlider):`

Constructor: `QSliderFloat(orientation, minimum, maximum, step)`

View In Hierarchy

QSliderFloat class.

Method | `__init__` | Initializes a slider supporting float values.
Method | `get_value` | Returns the slider value.
Method | `setValue` | Sets the slider value.
Instance Variable | `_step` | Undocumented

def __init__(self, orientation: `Qt.Orientation`, minimum: `float`, maximum: `float`, step: `float`):

Initializes a slider supporting float values.

Parameters
orientation: `Qt.Orientation` | Orientation
minimum: `float` | Minimum value
maximum: `float` | Maximum value
step: `float` | Step value

def get_value(self) -> `float`:

Returns the slider value.

Returns
`float` | Slider value

def setValue(self, value: `float`):

Sets the slider value.

Parameters
value: `float` | Slider value

_step =

Undocumented